==> jffnms_0.7.8.orig.tar.gz: jffnms-0.7.8/htdocs/admin/menu.php <==
<? 
    include ("../auth.php"); 
    
    $menus = array(
	"administration"=>array("title"=>"Administration",
	    "items"	=>array("users_cust","host_int","reports","internal","setup")),

	"internal"=>array("title"=>"Internal Configuration",
	    "items"	=>array("events","polling","sla_def","trig_filters","int_others")),

	"users_cust"	=>array("title"=>"Users and Customers", "image"=>"users",
	    "items"	=>array("customers","users","triggers_users_admin")),
	"customers"		=>array("title"=>"Customers", 		"type"=>"standard", 	"link"=>"clients", 	"image"=>"user2"),
	"users"			=>array("title"=>"Users",		"type"=>"admframe",	"link"=>"auth",		"image"=>"users"),
	"triggers_users_admin"	=>array("title"=>"Triggers Users",	"type"=>"standard",				"image"=>"event"),

	"host_int"	=>array("title"=>"Hosts and Interfaces", "image"=>"host",
	    "items"	=>array("zones","hosts","interfaces","nad","hosts_config","maps","satellites")),
	"zones"			=>array("title"=>"Zones", 		"type"=>"standard", 				"image"=>"world"),
	"hosts"			=>array("title"=>"Hosts",		"type"=>"admframe",				"image"=>"host" ),
	"interfaces"		=>array("title"=>"Interfaces",		"type"=>"intframe",				"image"=>"int1"	),
	"hosts_config"		=>array("title"=>"Hosts Saved Configs",	"type"=>"admin",				"image"=>"config"),
	"maps"			=>array("title"=>"SubMaps", 		"type"=>"stdframe", 				"image"=>"map2"	),
	"satellites"		=>array("title"=>"Satellites", 		"type"=>"admin", 				"image"=>""	),
	//"nad"			=>array("title"=>"Network Autodiscovery","type"=>"admframe",				"image"=>"world"),

	"events"	=>array("title"=>"Event Analyzer", "image"=>"event",
	    "items"	=>array("severity","event_types","syslog_types","traps_types","alarm_states")),
	"severity"		=>array("title"=>"Serveritys", 		"type"=>"standard", 				"image"=>""	),
	"event_types"		=>array("title"=>"Event Types",		"type"=>"standard",				"image"=>"event"),
	"syslog_types"		=>array("title"=>"Syslog Message Rules","type"=>"standard",				"image"=>""	),
	"traps_types"		=>array("title"=>"SNMP Trap Rules",	"type"=>"standard",				"image"=>""	),
	"alarm_states"		=>array("title"=>"Alarm States & Sounds","type"=>"standard",				"image"=>"alert"),

	"polling"	=>array("title"=>"Polling & Discovery", "image"=>"",
	    "items"	=>array("interface_types","pollers_groups","pollers","pollers_backend","graph_types","autodiscovery")),
	"interface_types"	=>array("title"=>"Interface Types",		"type"=>"standard",			"image"=>""	),
	"pollers_groups"	=>array("title"=>"Poller/Backend Grouping",	"type"=>"stdframe",			"image"=>""	),
	"pollers"		=>array("title"=>"Poller Items",		"type"=>"standard",			"image"=>""	),
	"pollers_backend"	=>array("title"=>"Backend Items",		"type"=>"standard",			"image"=>""	),
	"graph_types"		=>array("title"=>"Graph Types",			"type"=>"standard",			"image"=>"graph"),
	"autodiscovery"		=>array("title"=>"Autodiscovery Policy",	"type"=>"standard", 			"image"=>""	),

	"setup"			=>array("title"=>"System Setup and Checking",	"type"=>"raw",	"link"=>"/admin/setup.php", "image"=>""	),

	"sla_def"	=>array("title"=>"SLA Definitions", "image"=>"pen",
	    "items"	=>array("slas","slas_cond")),
	"slas"			=>array("title"=>"SLA Conditions Groups",		"type"=>"stdframe",		"image"=>"pen"	),
	"slas_cond"		=>array("title"=>"SLA Conditions Individual Definition","type"=>"standard",		"image"=>""	),

	"reports"	=>array("title"=>"Reports", "image"=>"text",
	    "items"	=>array("state_report","performance","journal","alarms")),
	"state_report"		=>array("title"=>"State & Availability","type"=>"intframe", 				"image"=>"text"	),
	"performance"		=>array("title"=>"Performance Graphs",	"type"=>"intframe",				"image"=>"graph"),
	"journal"		=>array("title"=>"Journal",		"type"=>"raw",	"link"=>"/admin/reports/journal_report.php", "image"=>""),
	"alarms"		=>array("title"=>"Alarm Editor",	"type"=>"intframe",				"image"=>"text"),
	
	"trig_filters"	=>array("title"=>"Triggers & Filters", "image"=>"query",
	    "items"	=>array("triggers","actions","filters","filters_fields")),
	"triggers"		=>array("title"=>"Triggers Configuration",	"type"=>"stdframe", 			"image"=>""	),
	"actions"		=>array("title"=>"Actions Definition",		"type"=>"standard",			"image"=>""	),
	"filters"		=>array("title"=>"Event Filters",		"type"=>"stdframe",			"image"=>"query"),
	"filters_fields"	=>array("title"=>"Filter Fields",		"type"=>"standard",			"image"=>""	),
	
	"int_others"	=>array("title"=>"Other Configurations", "image"=>"",
	    "items"	=>array("hosts_config_types","profiles_options","tools","interface_types_field_types")),
	"hosts_config_types"	=>array("title"=>"Host Config Commands",	"type"=>"standard", 			"image"=>""	),
	"profiles_options"	=>array("title"=>"Profiles Options",		"type"=>"admframe",			"image"=>"tag"	),
	"tools"			=>array("title"=>"Interface/Host Tools",	"type"=>"standard",			"image"=>"tool"	),
	"interface_types_field_types"=>array("title"=>"Interface Types Fields Types",	"type"=>"standard",		"image"=>""	),
	
	NULL
    );

    function process_url ($type, $link, $deep) {
	global $jffnms_rel_path;
    
	switch ($type) {
	    case "raw"		: $url = $jffnms_rel_path.$link; break;

	    case "standard"	: $url = "$jffnms_rel_path/admin/adm/adm_standard.php?admin_structure=".$link; break;
	    case "admin"	: $url = "$jffnms_rel_path/admin/adm/adm_".$link.".php"; break;
	
	    case "admframe"	: $url = "$jffnms_rel_path/admin/menu_frame.php?name1=".urlencode("adm/adm_".$link.".php?"); break;
	    case "stdframe"	: $url = "$jffnms_rel_path/admin/menu_frame.php?name1=".urlencode("adm/adm_standard.php?admin_structure=".$link); break;
	    case "intframe"	: $url = "$jffnms_rel_path/admin/menu_frame.php?menu=interface_list&size1=275&type=vertical&menu_type=".$link; break;

	    default		: $url = $_SERVER["SCRIPT_NAME"]."?menu=".$link."&show_frame=1&deep=$deep"; break;
	}
    
	return $url;
    } 

    if (!isset($menu)) $menu = "administration";
    if (!isset($deep)) $deep = 0;
    if (!isset($show_frame)) $show_frame = 1;
    
    $top_menu = $menus[$menu];
    
    if (is_array($top_menu))
	if (is_array($top_menu["items"])) {

	    if ($show_frame==0) {

		adm_control_header($top_menu["title"]);
		$deep++;

		foreach ($top_menu["items"] as $sub_menu_id) 
		    if ($sub_menu = $menus[$sub_menu_id]) {

			if (!isset($sub_menu["link"]))  $sub_menu["link"]=$sub_menu_id;
			if (!isset($sub_menu["type"]))  $sub_menu["type"]="";
			if (!isset($sub_menu["image"])) $sub_menu["image"]="";

			$url = process_url ($sub_menu["type"],$sub_menu["link"], $deep);
	
			adm_control_option ($sub_menu["title"], "menu$deep", $url, (($sub_menu["image"]=="")?"":$sub_menu["image"].".png"));
		    }
    
		adm_footer();

	    } else 
		echo "<HTML>\n<HEAD>\n<TITLE>".$top_menu["title"]." Menu</TITLE>\n</HEAD>\n".
		    "<frameset rows='20,*' FRAMEBORDER=0 FRAMESPACING=1 SCROLLING=no>\n".
		    "<frame SCROLLING='no'  noresize src='".$_SERVER["REQUEST_URI"]."&show_frame=0' name='menu$deep'>\n".
		    "<frame SCROLLING='yes' noresize src='$jffnms_rel_path/blank.html' name='menu".($deep+1)."'>\n".
		    "</frameset>\n</HTML>\n";
	} else {
	    $url = process_url ($top_menu["type"],$top_menu["link"], $deep);
	    Header ("Location: $url");
	    die();
	}
    else 
	die ("Wrong Menu ID ($menu)");
    
?>

==> jffnms_0.7.9.orig.tar.gz: jffnms-0.7.9/htdocs/admin/menu.php <==
<? 
    include ("../auth.php"); 
    
    $menus = array(
	"administration"=>array("title"=>"Administration",
	    "items"	=>array("users_cust","host_int","reports","internal","setup")),

	"internal"=>array("title"=>"Internal Configuration",
	    "items"	=>array("events","polling","sla_def","trig_filters","int_others")),

	"users_cust"	=>array("title"=>"Users and Customers", "image"=>"users",
	    "items"	=>array("customers","users","triggers_users_admin")),
	"customers"		=>array("title"=>"Customers", 		"type"=>"standard", 	"link"=>"clients", 	"image"=>"user2"),
	"users"			=>array("title"=>"Users",		"type"=>"admframe",	"link"=>"auth",		"image"=>"users"),
	"triggers_users_admin"	=>array("title"=>"Triggers Users",	"type"=>"standard",				"image"=>"event"),

	"host_int"	=>array("title"=>"Hosts and Interfaces", "image"=>"host",
	    "items"	=>array("zones","hosts","interfaces","nad","hosts_config","maps","satellites")),
	"zones"			=>array("title"=>"Zones", 		"type"=>"standard", 				"image"=>"world"),
	"hosts"			=>array("title"=>"Hosts",		"type"=>"admframe",				"image"=>"host" ),
	"interfaces"		=>array("title"=>"Interfaces",		"type"=>"intframe",				"image"=>"int1"	),
	"hosts_config"		=>array("title"=>"Hosts Saved Configs",	"type"=>"admin",				"image"=>"config"),
	"maps"			=>array("title"=>"SubMaps", 		"type"=>"stdframe", 				"image"=>"map2"	),
	"satellites"		=>array("title"=>"Satellites", 		"type"=>"admin", 				"image"=>""	),
	//"nad"			=>array("title"=>"Network Autodiscovery","type"=>"admframe",				"image"=>"world"),

	"events"	=>array("title"=>"Event Analyzer", "image"=>"event",
	    "items"	=>array("severity","event_types","syslog_types","traps_types","alarm_states")),
	"severity"		=>array("title"=>"Serverities",		"type"=>"standard", 				"image"=>""	),
	"event_types"		=>array("title"=>"Event Types",		"type"=>"standard",				"image"=>"event"),
	"syslog_types"		=>array("title"=>"Syslog Message Rules","type"=>"standard",				"image"=>""	),
	"traps_types"		=>array("title"=>"SNMP Trap Rules",	"type"=>"standard",				"image"=>""	),
	"alarm_states"		=>array("title"=>"Alarm States & Sounds","type"=>"standard",				"image"=>"alert"),

	"polling"	=>array("title"=>"Polling & Discovery", "image"=>"",
	    "items"	=>array("interface_types","pollers_groups","pollers","pollers_backend","graph_types","autodiscovery")),
	"interface_types"	=>array("title"=>"Interface Types",		"type"=>"standard",			"image"=>""	),
	"pollers_groups"	=>array("title"=>"Poller/Backend Grouping",	"type"=>"stdframe",			"image"=>""	),
	"pollers"		=>array("title"=>"Poller Items",		"type"=>"standard",			"image"=>""	),
	"pollers_backend"	=>array("title"=>"Backend Items",		"type"=>"standard",			"image"=>""	),
	"graph_types"		=>array("title"=>"Graph Types",			"type"=>"standard",			"image"=>"graph"),
	"autodiscovery"		=>array("title"=>"Autodiscovery Policy",	"type"=>"standard", 			"image"=>""	),

	"setup"			=>array("title"=>"System Setup and Checking",	"type"=>"raw",	"link"=>"/admin/setup.php", "image"=>""	),

	"sla_def"	=>array("title"=>"SLA Definitions", "image"=>"pen",
	    "items"	=>array("slas","slas_cond")),
	"slas"			=>array("title"=>"SLA Conditions Groups",		"type"=>"stdframe",		"image"=>"pen"	),
	"slas_cond"		=>array("title"=>"SLA Conditions Individual Definition","type"=>"standard",		"image"=>""	),

	"reports"	=>array("title"=>"Reports", "image"=>"text",
	    "items"	=>array("state_report","performance","journal","alarms")),
	"state_report"		=>array("title"=>"State & Availability","type"=>"intframe", 				"image"=>"text"	),
	"performance"		=>array("title"=>"Performance Graphs",	"type"=>"intframe",				"image"=>"graph"),
	"journal"		=>array("title"=>"Journal",		"type"=>"raw",	"link"=>"/admin/reports/journal_report.php", "image"=>""),
	"alarms"		=>array("title"=>"Alarm Editor",	"type"=>"intframe",				"image"=>"text"),
	
	"trig_filters"	=>array("title"=>"Triggers & Filters", "image"=>"query",
	    "items"	=>array("triggers","actions","filters","filters_fields")),
	"triggers"		=>array("title"=>"Triggers Configuration",	"type"=>"stdframe", 			"image"=>""	),
	"actions"		=>array("title"=>"Actions Definition",		"type"=>"standard",			"image"=>""	),
	"filters"		=>array("title"=>"Event Filters",		"type"=>"stdframe",			"image"=>"query"),
	"filters_fields"	=>array("title"=>"Filter Fields",		"type"=>"standard",			"image"=>""	),
	
	"int_others"	=>array("title"=>"Other Configurations", "image"=>"",
	    "items"	=>array("hosts_config_types","profiles_options","tools","interface_types_field_types")),
	"hosts_config_types"	=>array("title"=>"Host Config Commands",	"type"=>"standard", 			"image"=>""	),
	"profiles_options"	=>array("title"=>"Profiles Options",		"type"=>"admframe",			"image"=>"tag"	),
	"tools"			=>array("title"=>"Interface/Host Tools",	"type"=>"standard",			"image"=>"tool"	),
	"interface_types_field_types"=>array("title"=>"Interface Types Fields Types",	"type"=>"standard",		"image"=>""	),
	
	NULL
    );

    function process_url ($type, $link, $deep) {
	global $jffnms_rel_path;
    
	switch ($type) {
	    case "raw"		: $url = $jffnms_rel_path.$link; break;

	    case "standard"	: $url = "$jffnms_rel_path/admin/adm/adm_standard.php?admin_structure=".$link; break;
	    case "admin"	: $url = "$jffnms_rel_path/admin/adm/adm_".$link.".php"; break;
	
	    case "admframe"	: $url = "$jffnms_rel_path/admin/menu_frame.php?name1=".urlencode("adm/adm_".$link.".php?"); break;
	    case "stdframe"	: $url = "$jffnms_rel_path/admin/menu_frame.php?name1=".urlencode("adm/adm_standard.php?admin_structure=".$link); break;
	    case "intframe"	: $url = "$jffnms_rel_path/admin/menu_frame.php?menu=interface_list&size1=275&type=vertical&menu_type=".$link; break;

	    default		: $url = $_SERVER["SCRIPT_NAME"]."?menu=".$link."&show_frame=1&deep=$deep"; break;
	}
    
	return $url;
    } 

    if (!isset($menu)) $menu = "administration";
    if (!isset($deep)) $deep = 0;
    if (!isset($show_frame)) $show_frame = 1;
    
    $top_menu = $menus[$menu];
    
    if (is_array($top_menu))
	if (is_array($top_menu["items"])) {

	    if ($show_frame==0) {

		adm_control_header($top_menu["title"]);
		$deep++;

		foreach ($top_menu["items"] as $sub_menu_id) 
		    if ($sub_menu = $menus[$sub_menu_id]) {

			if (!isset($sub_menu["link"]))  $sub_menu["link"]=$sub_menu_id;
			if (!isset($sub_menu["type"]))  $sub_menu["type"]="";
			if (!isset($sub_menu["image"])) $sub_menu["image"]="";

			$url = process_url ($sub_menu["type"],$sub_menu["link"], $deep);
	
			adm_control_option ($sub_menu["title"], "menu$deep", $url, (($sub_menu["image"]=="")?"":$sub_menu["image"].".png"));
		    }
    
		adm_footer();

	    } else 
		echo "<HTML>\n<HEAD>\n<TITLE>".$top_menu["title"]." Menu</TITLE>\n</HEAD>\n".
		    "<frameset rows='20,*' FRAMEBORDER=0 FRAMESPACING=1 SCROLLING=no>\n".
		    "<frame SCROLLING='no'  noresize src='".$_SERVER["REQUEST_URI"]."&show_frame=0' name='menu$deep'>\n".
		    "<frame SCROLLING='yes' noresize src='$jffnms_rel_path/blank.html' name='menu".($deep+1)."'>\n".
		    "</frameset>\n</HTML>\n";
	} else {
	    $url = process_url ($top_menu["type"],$top_menu["link"], $deep);
	    Header ("Location: $url");
	    die();
	}
    else 
	die ("Wrong Menu ID ($menu)");
    
?>
